@@ -7,13 +7,12 @@ import os
 
 from reV.econ import Econ
 from reV.generation import Gen
-from reV.handlers import (NSRDB, MultiFileNSRDB, MultiFileWTK, Resource,
-                          SolarResource, WindResource)
+from reV.handlers import Outputs, ExclusionLayers
 from reV.pipeline import Pipeline, Status
 from reV.rep_profiles import RepProfiles
-from reV.supply_curve import (SupplyCurveAggregation, ExclusionMask,
-                              ExclusionMaskFromDict, SupplyCurve,
-                              SupplyCurvePointSummary, TechMapping)
+from reV.supply_curve import (Aggregation, ExclusionMask,
+                              ExclusionMaskFromDict, SupplyCurveAggregation,
+                              SupplyCurve, TechMapping)
 from reV.version import __version__
 
 __author__ = """Galen Maclaurin"""
