@@ -10,18 +10,18 @@ import pprint
 import time
 from warnings import warn
 
-from reV.generation.cli_gen import get_node_name_fout, make_fout
 from reV.config.project_points import ProjectPoints, PointsControl
 from reV.config.sam_analysis_configs import EconConfig
 from reV.econ.econ import Econ
-from reV.utilities.cli_dtypes import (INT, STR, SAMFILES, PROJECTPOINTS,
-                                      INTLIST, STRLIST)
-from reV.utilities.execution import SLURM, SubprocessManager
-from reV.utilities.loggers import init_mult
-from reV.pipeline.status import Status
 from reV.generation.cli_gen import main
-from reV.utilities.utilities import parse_year
+from reV.generation.cli_gen import get_node_name_fout, make_fout
+from reV.pipeline.status import Status
+from reV.utilities.cli_dtypes import SAMFILES, PROJECTPOINTS
 
+from rex.utilities.cli_dtypes import INT, STR, INTLIST, STRLIST
+from rex.utilities.execution import SLURM, SubprocessManager
+from rex.utilities.loggers import init_mult
+from rex.utilities.utilities import parse_year
 
 logger = logging.getLogger(__name__)
 
