@@ -7,10 +7,11 @@ import logging
 import json
 import numpy as np
 
-from reV.handlers.parse_keys import parse_keys
-from reV.handlers.resource import ResourceDataset
 from reV.utilities.exceptions import HandlerKeyError
 
+from rex.utilities.parse_keys import parse_keys
+from rex.resource import ResourceDataset
+
 logger = logging.getLogger(__name__)
 
 
@@ -39,6 +40,7 @@ class ExclusionLayers:
 
     def __repr__(self):
         msg = "{} for {}".format(self.__class__.__name__, self.h5_file)
+
         return msg
 
     def __enter__(self):
@@ -98,6 +100,7 @@ class ExclusionLayers:
             N = self.shape[0] * self.shape[1]
             self._iarr = np.arange(N, dtype=np.uint32)
             self._iarr = self._iarr.reshape(self.shape)
+
         return self._iarr
 
     @property
@@ -124,6 +127,7 @@ class ExclusionLayers:
         """
         layers = [ds for ds in self.h5
                   if ds != 'meta']
+
         return layers
 
     @property
@@ -136,7 +140,11 @@ class ExclusionLayers:
         shape : tuple
             Shape of exclusion array (latitude, longitude)
         """
-        return self.h5.attrs['shape']
+        shape = self.h5.attrs.get('shape', None)
+        if shape is None:
+            shape = self.h5['latitude'].shape
+
+        return tuple(shape)
 
     @property
     def latitude(self):
@@ -175,6 +183,7 @@ class ExclusionLayers:
             GeoTiff profile for single exclusion layer
         """
         profile = json.loads(self.h5[layer].attrs['profile'])
+
         return profile
 
     def get_layer_values(self, layer):
@@ -192,6 +201,7 @@ class ExclusionLayers:
             GeoTiff values for single exclusion layer
         """
         values = self.h5[layer][...]
+
         return values
 
     def get_layer_description(self, layer):
@@ -209,6 +219,7 @@ class ExclusionLayers:
             Description of layer
         """
         description = self.h5[layer].attrs['description']
+
         return description
 
     def get_nodata_value(self, layer):
@@ -227,6 +238,7 @@ class ExclusionLayers:
         """
         profile = self.get_layer_profile(layer)
         nodata = profile.get('nodata', None)
+
         return nodata
 
     def _get_latitude(self, *ds_slice):
