@@ -11,11 +11,12 @@ from pandas.api.types import CategoricalDtype
 import time
 
 from reV.version import __version__
-from reV.handlers.resource import Resource
-from reV.handlers.parse_keys import parse_keys, parse_slice
 from reV.utilities.exceptions import (HandlerRuntimeError, HandlerKeyError,
                                       HandlerValueError)
 
+from rex.resource import Resource
+from rex.utilities.parse_keys import parse_keys, parse_slice
+
 logger = logging.getLogger(__name__)
 
 
@@ -291,7 +292,9 @@ class Outputs(Resource):
         """
         self._time_index = time_index
         if isinstance(time_index, pd.DatetimeIndex):
-            time_index = np.array(time_index.astype(str), dtype='S20')
+            time_index = time_index.astype(str)
+            dtype = "S{}".format(len(time_index[0]))
+            time_index = np.array(time_index, dtype=dtype)
 
         if ds in self.datasets:
             self.update_dset(ds, time_index)
