@@ -16,14 +16,14 @@ from scipy.spatial import cKDTree
 import logging
 from warnings import warn
 
-from reV.handlers.collection import DatasetCollector
 from reV.generation.generation import Gen
+from reV.handlers.collection import DatasetCollector
 from reV.handlers.outputs import Outputs
 from reV.offshore.orca import ORCA_LCOE
-from reV.utilities.execution import SpawnProcessPool
 from reV.utilities.exceptions import (OffshoreWindInputWarning,
                                       NearestNeighborError)
 
+from rex.utilities.execution import SpawnProcessPool
 
 logger = logging.getLogger(__name__)
 
@@ -739,7 +739,9 @@ class Offshore:
         """Run offshore gen aggregation and ORCA econ compute in parallel."""
 
         futures = {}
-        with SpawnProcessPool(self._max_workers) as exe:
+        loggers = __name__
+        with SpawnProcessPool(max_workers=self._max_workers,
+                              loggers=loggers) as exe:
 
             iterator = self.meta_out_offshore.iterrows()
             for i, (ifarm, meta) in enumerate(iterator):
