@@ -15,13 +15,14 @@ import os
 import pandas as pd
 from scipy import stats
 
-from reV.handlers.resource import Resource
-from reV.handlers.outputs import Outputs
-from reV.utilities.execution import SpawnProcessPool
-from reV.utilities.exceptions import FileInputError, DataShapeError
-from reV.utilities.utilities import parse_year
-from reV.utilities.loggers import log_mem
 
+from reV.handlers.outputs import Outputs
+from reV.utilities.exceptions import FileInputError, DataShapeError
+
+from rex.resource import Resource
+from rex.utilities.execution import SpawnProcessPool
+from rex.utilities.utilities import parse_year
+from rex.utilities.loggers import log_mem
 
 logger = logging.getLogger(__name__)
 
@@ -988,7 +989,9 @@ class RepProfiles(RepProfilesBase):
         for iter_chunk in iter_chunks:
             logger.debug('Starting process pool...')
             futures = {}
-            with SpawnProcessPool(max_workers=max_workers) as exe:
+            loggers = __name__
+            with SpawnProcessPool(max_workers=max_workers,
+                                  loggers=loggers) as exe:
                 for i in iter_chunk:
                     row = self.meta.loc[i, :]
                     region_dict = {k: v for (k, v) in row.to_dict().items()
@@ -1209,7 +1212,9 @@ class AggregatedRepProfiles(RepProfilesBase):
         for iter_chunk in iter_chunks:
             logger.debug('Starting process pool...')
             futures = {}
-            with SpawnProcessPool(max_workers=max_workers) as exe:
+            loggers = __name__
+            with SpawnProcessPool(max_workers=max_workers,
+                                  loggers=loggers) as exe:
                 for i in iter_chunk:
                     row = self.meta.loc[i, :]
                     row = pd.DataFrame(row).T
